@@ -1,8 +1,11 @@
 from __future__ import absolute_import
+from pymycobot.mycobot import MyCobot
+from pymycobot.generate import MycobotCommandGenerater
+from pymycobot.genre import Angle, Coord
 
-__all__ = ["mycobot", "genre"]
+__all__ = ["MyCobot", "MycobotCommandGenerater", "Angle", "Coord"]
 
-__version__ = "2.4.2"
+__version__ = "2.5.2"
 __author__ = "Zachary zhang"
 __email__ = "lijun.zhang@elephantrobotics.com"
 __git_url__ = "https://github.com/elephantrobotics/pymycobot"
